# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from mett_dataportal_sdk.models.paginated_response_schema import PaginatedResponseSchema
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class PooledTTPInteractionsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_compound_interactions(
        self,
        compound: Annotated[StrictStr, Field(description="Name of the compound")],
        compound2: Annotated[
            Optional[StrictStr],
            Field(
                description="Name of the compound to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter.")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr], Field(description="Isolate name filter.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get compound interactions

        Get all protein-compound interactions for a specific compound.

        :param compound: Name of the compound (required)
        :type compound: str
        :param compound2: Name of the compound to get interactions for (provided as path parameter).
        :type compound2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param species_acronym: Species acronym filter.
        :type species_acronym: str
        :param isolate_name: Isolate name filter.
        :type isolate_name: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_compound_interactions_serialize(
            compound=compound,
            compound2=compound2,
            hit_calling=hit_calling,
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_compound_interactions_with_http_info(
        self,
        compound: Annotated[StrictStr, Field(description="Name of the compound")],
        compound2: Annotated[
            Optional[StrictStr],
            Field(
                description="Name of the compound to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter.")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr], Field(description="Isolate name filter.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get compound interactions

        Get all protein-compound interactions for a specific compound.

        :param compound: Name of the compound (required)
        :type compound: str
        :param compound2: Name of the compound to get interactions for (provided as path parameter).
        :type compound2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param species_acronym: Species acronym filter.
        :type species_acronym: str
        :param isolate_name: Isolate name filter.
        :type isolate_name: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_compound_interactions_serialize(
            compound=compound,
            compound2=compound2,
            hit_calling=hit_calling,
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_compound_interactions_without_preload_content(
        self,
        compound: Annotated[StrictStr, Field(description="Name of the compound")],
        compound2: Annotated[
            Optional[StrictStr],
            Field(
                description="Name of the compound to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        species_acronym: Annotated[
            Optional[StrictStr], Field(description="Species acronym filter.")
        ] = None,
        isolate_name: Annotated[
            Optional[StrictStr], Field(description="Isolate name filter.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get compound interactions

        Get all protein-compound interactions for a specific compound.

        :param compound: Name of the compound (required)
        :type compound: str
        :param compound2: Name of the compound to get interactions for (provided as path parameter).
        :type compound2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param species_acronym: Species acronym filter.
        :type species_acronym: str
        :param isolate_name: Isolate name filter.
        :type isolate_name: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_compound_interactions_serialize(
            compound=compound,
            compound2=compound2,
            hit_calling=hit_calling,
            species_acronym=species_acronym,
            isolate_name=isolate_name,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ttp_endpoints_get_compound_interactions_serialize(
        self,
        compound,
        compound2,
        hit_calling,
        species_acronym,
        isolate_name,
        min_ttp_score,
        sort_field,
        sort_order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if compound is not None:
            _path_params["compound"] = compound
        # process the query parameters
        if compound2 is not None:
            _query_params.append(("compound", compound2))

        if hit_calling is not None:
            _query_params.append(("hit_calling", hit_calling))

        if species_acronym is not None:
            _query_params.append(("species_acronym", species_acronym))

        if isolate_name is not None:
            _query_params.append(("isolate_name", isolate_name))

        if min_ttp_score is not None:
            _query_params.append(("min_ttp_score", min_ttp_score))

        if sort_field is not None:
            _query_params.append(("sort_field", sort_field))

        if sort_order is not None:
            _query_params.append(("sort_order", sort_order))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ttp/compound/{compound}/interactions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_gene_interactions(
        self,
        locus_tag: Annotated[StrictStr, Field(description="Locus tag of the gene")],
        locus_tag2: Annotated[
            Optional[StrictStr],
            Field(
                description="Locus tag of the gene to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        pool_a: Annotated[
            Optional[StrictStr], Field(description="Filter by poolA.")
        ] = None,
        pool_b: Annotated[
            Optional[StrictStr], Field(description="Filter by poolB.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get gene interactions

        Get all protein-compound interactions for a specific gene.

        :param locus_tag: Locus tag of the gene (required)
        :type locus_tag: str
        :param locus_tag2: Locus tag of the gene to get interactions for (provided as path parameter).
        :type locus_tag2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param pool_a: Filter by poolA.
        :type pool_a: str
        :param pool_b: Filter by poolB.
        :type pool_b: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_gene_interactions_serialize(
            locus_tag=locus_tag,
            locus_tag2=locus_tag2,
            hit_calling=hit_calling,
            pool_a=pool_a,
            pool_b=pool_b,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_gene_interactions_with_http_info(
        self,
        locus_tag: Annotated[StrictStr, Field(description="Locus tag of the gene")],
        locus_tag2: Annotated[
            Optional[StrictStr],
            Field(
                description="Locus tag of the gene to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        pool_a: Annotated[
            Optional[StrictStr], Field(description="Filter by poolA.")
        ] = None,
        pool_b: Annotated[
            Optional[StrictStr], Field(description="Filter by poolB.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get gene interactions

        Get all protein-compound interactions for a specific gene.

        :param locus_tag: Locus tag of the gene (required)
        :type locus_tag: str
        :param locus_tag2: Locus tag of the gene to get interactions for (provided as path parameter).
        :type locus_tag2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param pool_a: Filter by poolA.
        :type pool_a: str
        :param pool_b: Filter by poolB.
        :type pool_b: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_gene_interactions_serialize(
            locus_tag=locus_tag,
            locus_tag2=locus_tag2,
            hit_calling=hit_calling,
            pool_a=pool_a,
            pool_b=pool_b,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_gene_interactions_without_preload_content(
        self,
        locus_tag: Annotated[StrictStr, Field(description="Locus tag of the gene")],
        locus_tag2: Annotated[
            Optional[StrictStr],
            Field(
                description="Locus tag of the gene to get interactions for (provided as path parameter)."
            ),
        ] = None,
        hit_calling: Annotated[
            Optional[StrictBool], Field(description="Filter by hit calling status.")
        ] = None,
        pool_a: Annotated[
            Optional[StrictStr], Field(description="Filter by poolA.")
        ] = None,
        pool_b: Annotated[
            Optional[StrictStr], Field(description="Filter by poolB.")
        ] = None,
        min_ttp_score: Annotated[
            Optional[Union[StrictFloat, StrictInt]],
            Field(description="Minimum TTP score threshold."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get gene interactions

        Get all protein-compound interactions for a specific gene.

        :param locus_tag: Locus tag of the gene (required)
        :type locus_tag: str
        :param locus_tag2: Locus tag of the gene to get interactions for (provided as path parameter).
        :type locus_tag2: str
        :param hit_calling: Filter by hit calling status.
        :type hit_calling: bool
        :param pool_a: Filter by poolA.
        :type pool_a: str
        :param pool_b: Filter by poolB.
        :type pool_b: str
        :param min_ttp_score: Minimum TTP score threshold.
        :type min_ttp_score: float
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_get_gene_interactions_serialize(
            locus_tag=locus_tag,
            locus_tag2=locus_tag2,
            hit_calling=hit_calling,
            pool_a=pool_a,
            pool_b=pool_b,
            min_ttp_score=min_ttp_score,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ttp_endpoints_get_gene_interactions_serialize(
        self,
        locus_tag,
        locus_tag2,
        hit_calling,
        pool_a,
        pool_b,
        min_ttp_score,
        sort_field,
        sort_order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if locus_tag is not None:
            _path_params["locus_tag"] = locus_tag
        # process the query parameters
        if locus_tag2 is not None:
            _query_params.append(("locus_tag", locus_tag2))

        if hit_calling is not None:
            _query_params.append(("hit_calling", hit_calling))

        if pool_a is not None:
            _query_params.append(("poolA", pool_a))

        if pool_b is not None:
            _query_params.append(("poolB", pool_b))

        if min_ttp_score is not None:
            _query_params.append(("min_ttp_score", min_ttp_score))

        if sort_field is not None:
            _query_params.append(("sort_field", sort_field))

        if sort_order is not None:
            _query_params.append(("sort_order", sort_order))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ttp/gene/{locus_tag}/interactions",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_ttp_metadata(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get TTP metadata

        Get metadata about the TTP dataset including counts, available compounds, and score ranges.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_serialize(
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get TTP metadata

        Get metadata about the TTP dataset including counts, available compounds, and score ranges.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_serialize(
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get TTP metadata

        Get metadata about the TTP dataset including counts, available compounds, and score ranges.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = (
            self._dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_serialize(
                _request_auth=_request_auth,
                _content_type=_content_type,
                _headers=_headers,
                _host_index=_host_index,
            )
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ttp_endpoints_get_ttp_metadata_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ttp/metadata",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_search_interactions(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(
                description="Free-text search term to match against gene names, locus tags, or compound names."
            ),
        ] = None,
        page: Annotated[
            Optional[StrictInt],
            Field(description="Page number for pagination (1-based)."),
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of interactions to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr],
            Field(
                description="Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound')."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedResponseSchema:
        """Search TTP interactions

        Search for protein-compound interactions with basic filtering and pagination.

        :param query: Free-text search term to match against gene names, locus tags, or compound names.
        :type query: str
        :param page: Page number for pagination (1-based).
        :type page: int
        :param per_page: Number of interactions to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound').
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_search_interactions_serialize(
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_search_interactions_with_http_info(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(
                description="Free-text search term to match against gene names, locus tags, or compound names."
            ),
        ] = None,
        page: Annotated[
            Optional[StrictInt],
            Field(description="Page number for pagination (1-based)."),
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of interactions to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr],
            Field(
                description="Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound')."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedResponseSchema]:
        """Search TTP interactions

        Search for protein-compound interactions with basic filtering and pagination.

        :param query: Free-text search term to match against gene names, locus tags, or compound names.
        :type query: str
        :param page: Page number for pagination (1-based).
        :type page: int
        :param per_page: Number of interactions to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound').
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_search_interactions_serialize(
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_interactions_ttp_endpoints_search_interactions_without_preload_content(
        self,
        query: Annotated[
            Optional[StrictStr],
            Field(
                description="Free-text search term to match against gene names, locus tags, or compound names."
            ),
        ] = None,
        page: Annotated[
            Optional[StrictInt],
            Field(description="Page number for pagination (1-based)."),
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of interactions to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr],
            Field(
                description="Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound')."
            ),
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search TTP interactions

        Search for protein-compound interactions with basic filtering and pagination.

        :param query: Free-text search term to match against gene names, locus tags, or compound names.
        :type query: str
        :param page: Page number for pagination (1-based).
        :type page: int
        :param per_page: Number of interactions to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by (e.g., 'ttp_score', 'fdr', 'compound').
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_interactions_ttp_endpoints_search_interactions_serialize(
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "PaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_interactions_ttp_endpoints_search_interactions_serialize(
        self,
        query,
        page,
        per_page,
        sort_field,
        sort_order,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_field is not None:
            _query_params.append(("sort_field", sort_field))

        if sort_order is not None:
            _query_params.append(("sort_order", sort_order))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/ttp/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""Mutant growth CLI commands."""

from __future__ import annotations

from typing import List, Optional

import typer  # type: ignore[import]

from ..utils import comma_join, ensure_client, handle_raw_response, merge_params

mutant_app = typer.Typer(help="Mutant growth endpoints")


@mutant_app.command("search")
def mutant_growth_search(
    ctx: typer.Context,
    locus_tags: Optional[List[str]] = typer.Option(None, "--locus-tag"),
    uniprot_ids: Optional[List[str]] = typer.Option(None, "--uniprot"),
    media: Optional[str] = typer.Option(None, "--media"),
    experimental_condition: Optional[str] = typer.Option(None, "--condition"),
    min_doubling_time: Optional[float] = typer.Option(None, "--min-doubling-time"),
    max_doubling_time: Optional[float] = typer.Option(None, "--max-doubling-time"),
    exclude_double_picked: Optional[bool] = typer.Option(
        None, "--exclude-double-picked"
    ),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tags": comma_join(locus_tags),
            "uniprot_ids": comma_join(uniprot_ids),
            "media": media,
            "experimental_condition": experimental_condition,
            "min_doubling_time": min_doubling_time,
            "max_doubling_time": max_doubling_time,
            "exclude_double_picked": exclude_double_picked,
        }
    )
    response = client.raw_request(
        "GET", "/api/mutant-growth/search", params=params, format=format
    )
    handle_raw_response(response, format, title="Mutant growth search")



from __future__ import annotations

from click.testing import CliRunner
from typer.main import get_command

from mett_client.cli.main import app as cli_app
from .test_cli import _patch_dummy_client


runner = CliRunner()
cli_cmd = get_command(cli_app)


def test_species_list(monkeypatch) -> None:
    """Friendly CLI: mett species list --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(cli_cmd, ["species", "list", "--format", "json"])
    assert result.exit_code == 0


def test_species_genomes_basic(monkeypatch) -> None:
    """Friendly CLI: mett species genomes bu --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(cli_cmd, ["species", "genomes", "bu", "--format", "json"])
    assert result.exit_code == 0


def test_species_genomes_with_query(monkeypatch) -> None:
    """Friendly CLI: mett species genomes bu --query BU_ATCC --page 1 --format json"""
    _patch_dummy_client(monkeypatch)
    result = runner.invoke(
        cli_cmd,
        [
            "species",
            "genomes",
            "bu",
            "--query",
            "BU_ATCC",
            "--page",
            "1",
            "--format",
            "json",
        ],
    )
    assert result.exit_code == 0



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from mett_dataportal_sdk.models.genome_paginated_response_schema import (
    GenomePaginatedResponseSchema,
)
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class SpeciesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_all_species_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all species

        Get all available species

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_all_species_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_get_all_species_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenomePaginatedResponseSchema:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species_with_http_info(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenomePaginatedResponseSchema]:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_get_genomes_by_species_without_preload_content(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[Optional[StrictStr]]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get genomes by species

        Retrieves genomes under a given species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[Optional[str]]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_get_genomes_by_species_serialize(
        self,
        species_acronym,
        query,
        page,
        per_page,
        sort_field,
        sort_order,
        isolates,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {
            "isolates": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if species_acronym is not None:
            _path_params["species_acronym"] = species_acronym
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_field is not None:
            _query_params.append(("sortField", sort_field))

        if sort_order is not None:
            _query_params.append(("sortOrder", sort_order))

        if isolates is not None:
            _query_params.append(("isolates", isolates))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/{species_acronym}/genomes",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GenomePaginatedResponseSchema:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_with_http_info(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GenomePaginatedResponseSchema]:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_without_preload_content(
        self,
        species_acronym: Annotated[
            StrictStr, Field(description="Acronym for the species (BU or PV).")
        ],
        query: Annotated[
            Optional[StrictStr],
            Field(description="Search term to match against genome names or metadata."),
        ] = None,
        page: Annotated[
            Optional[StrictInt], Field(description="Page number to retrieve.")
        ] = None,
        per_page: Annotated[
            Optional[StrictInt],
            Field(description="Number of genomes to return per page."),
        ] = None,
        sort_field: Annotated[
            Optional[StrictStr], Field(description="Field to sort results by.")
        ] = None,
        sort_order: Annotated[
            Optional[StrictStr], Field(description="Sort order: 'asc' or 'desc'.")
        ] = None,
        isolates: Annotated[
            Optional[List[StrictStr]],
            Field(description="Optional list of isolate names to filter."),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search genomes by species and query string

        Performs a search for genomes within a specific species with pagination and sorting.

        :param species_acronym: Acronym for the species (BU or PV). (required)
        :type species_acronym: str
        :param query: Search term to match against genome names or metadata.
        :type query: str
        :param page: Page number to retrieve.
        :type page: int
        :param per_page: Number of genomes to return per page.
        :type per_page: int
        :param sort_field: Field to sort results by.
        :type sort_field: str
        :param sort_order: Sort order: 'asc' or 'desc'.
        :type sort_order: str
        :param isolates: Optional list of isolate names to filter.
        :type isolates: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
            species_acronym=species_acronym,
            query=query,
            page=page,
            per_page=per_page,
            sort_field=sort_field,
            sort_order=sort_order,
            isolates=isolates,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "GenomePaginatedResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_core_species_endpoints_search_genomes_by_species_and_string_serialize(
        self,
        species_acronym,
        query,
        page,
        per_page,
        sort_field,
        sort_order,
        isolates,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {
            "isolates": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if species_acronym is not None:
            _path_params["species_acronym"] = species_acronym
        # process the query parameters
        if query is not None:
            _query_params.append(("query", query))

        if page is not None:
            _query_params.append(("page", page))

        if per_page is not None:
            _query_params.append(("per_page", per_page))

        if sort_field is not None:
            _query_params.append(("sortField", sort_field))

        if sort_order is not None:
            _query_params.append(("sortOrder", sort_order))

        if isolates is not None:
            _query_params.append(("isolates", isolates))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/species/{species_acronym}/genomes/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class GeneAdvancedSearchQuerySchema(BaseModel):
    """
    Schema for advanced gene search across multiple genomes/species with filters.
    """  # noqa: E501

    isolates: Optional[StrictStr] = Field(
        default="", description="Comma-separated list of isolate names to filter."
    )
    species_acronym: Optional[StrictStr] = None
    locus_tag: Optional[StrictStr] = None
    query: Optional[StrictStr] = Field(
        default="",
        description="Free-text search string for gene names, locus tags, or annotations.",
    )
    filter: Optional[StrictStr] = None
    filter_operators: Optional[StrictStr] = None
    page: Optional[StrictInt] = Field(
        default=1, description="Page number for pagination (1-based)."
    )
    per_page: Optional[StrictInt] = Field(
        default=20, description="Number of genes to return per page."
    )
    sort_field: Optional[StrictStr] = None
    sort_order: Optional[StrictStr] = None
    seq_id: Optional[StrictStr] = None
    start_position: Optional[StrictInt] = None
    end_position: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = [
        "isolates",
        "species_acronym",
        "locus_tag",
        "query",
        "filter",
        "filter_operators",
        "page",
        "per_page",
        "sort_field",
        "sort_order",
        "seq_id",
        "start_position",
        "end_position",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GeneAdvancedSearchQuerySchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if species_acronym (nullable) is None
        # and model_fields_set contains the field
        if self.species_acronym is None and "species_acronym" in self.model_fields_set:
            _dict["species_acronym"] = None

        # set to None if locus_tag (nullable) is None
        # and model_fields_set contains the field
        if self.locus_tag is None and "locus_tag" in self.model_fields_set:
            _dict["locus_tag"] = None

        # set to None if filter (nullable) is None
        # and model_fields_set contains the field
        if self.filter is None and "filter" in self.model_fields_set:
            _dict["filter"] = None

        # set to None if filter_operators (nullable) is None
        # and model_fields_set contains the field
        if (
            self.filter_operators is None
            and "filter_operators" in self.model_fields_set
        ):
            _dict["filter_operators"] = None

        # set to None if sort_field (nullable) is None
        # and model_fields_set contains the field
        if self.sort_field is None and "sort_field" in self.model_fields_set:
            _dict["sort_field"] = None

        # set to None if sort_order (nullable) is None
        # and model_fields_set contains the field
        if self.sort_order is None and "sort_order" in self.model_fields_set:
            _dict["sort_order"] = None

        # set to None if seq_id (nullable) is None
        # and model_fields_set contains the field
        if self.seq_id is None and "seq_id" in self.model_fields_set:
            _dict["seq_id"] = None

        # set to None if start_position (nullable) is None
        # and model_fields_set contains the field
        if self.start_position is None and "start_position" in self.model_fields_set:
            _dict["start_position"] = None

        # set to None if end_position (nullable) is None
        # and model_fields_set contains the field
        if self.end_position is None and "end_position" in self.model_fields_set:
            _dict["end_position"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GeneAdvancedSearchQuerySchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "isolates": obj.get("isolates")
                if obj.get("isolates") is not None
                else "",
                "species_acronym": obj.get("species_acronym"),
                "locus_tag": obj.get("locus_tag"),
                "query": obj.get("query") if obj.get("query") is not None else "",
                "filter": obj.get("filter"),
                "filter_operators": obj.get("filter_operators"),
                "page": obj.get("page") if obj.get("page") is not None else 1,
                "per_page": obj.get("per_page")
                if obj.get("per_page") is not None
                else 20,
                "sort_field": obj.get("sort_field"),
                "sort_order": obj.get("sort_order"),
                "seq_id": obj.get("seq_id"),
                "start_position": obj.get("start_position"),
                "end_position": obj.get("end_position"),
            }
        )
        return _obj



"""METT Data Portal Python client and CLI."""

from .client import DataPortalClient
from .config import Config, get_config
from .constants import DEFAULT_BASE_URL
from .exceptions import APIError, AuthenticationError, ConfigurationError
from .version import __version__

__all__ = [
    "DataPortalClient",
    "Config",
    "get_config",
    "DEFAULT_BASE_URL",
    "APIError",
    "AuthenticationError",
    "ConfigurationError",
    "__version__",
]



"""Utility functions for the METT Data Portal client."""

from __future__ import annotations

import re
from typing import Any, Dict, Optional

from .models import Species


def normalize_params(params: Dict[str, Any]) -> Dict[str, Any]:
    """Normalize parameter keys to snake_case and filter None values."""
    normalized: Dict[str, Any] = {}
    for key, value in params.items():
        if value is None:
            continue
        if key.startswith("_"):
            normalized[key] = value
            continue
        if any(ch.isupper() for ch in key):
            snake = re.sub(r"(?<!^)(?=[A-Z])", "_", key).lower()
            normalized[snake] = value
        else:
            normalized[key] = value
    return normalized


def normalize_species_entry(entry: Any) -> Species:
    """Normalize a species entry from various API response formats."""
    if hasattr(entry, "model_dump"):
        entry = entry.model_dump()
    if not isinstance(entry, dict):
        return {
            "species_scientific_name": str(entry),
            "species_acronym": None,
            "description": None,
            "taxonomy_id": None,
        }

    def _first(*keys: str) -> Optional[Any]:
        for key in keys:
            if key in entry and entry[key] not in (None, ""):
                return entry[key]
        return None

    return {
        "species_acronym": _first("species_acronym", "acronym", "short_name"),
        "species_scientific_name": _first(
            "species_scientific_name", "scientific_name", "name"
        ),
        "description": _first("description", "common_name"),
        "taxonomy_id": _first("taxonomy_id", "tax_id"),
    }


__all__ = ["normalize_params", "normalize_species_entry"]
